@@ -16,6 +16,9 @@
  *
  */
 
+#define _GNU_SOURCE
+#include <stdio.h>
+
 #include "kylin-network-interface.h"
 
 #include <netinet/in.h>
